@@ -1,16 +1,20 @@
 package Class::DBI::mysql;
 
+$VERSION = '0.22';
+
 =head1 NAME
 
 Class::DBI::mysql - Extensions to Class::DBI for MySQL
 
 =head1 SYNOPSIS
 
-  package Film.pm;
+  package Film;
   use base 'Class::DBI::mysql';
   __PACKAGE__->set_db('Main', 'dbi:mysql:dbname', 'user', 'password');
   __PACKAGE__->set_up_table("film");
 
+  __PACKAGE__->autoinflate(dates => 'Time::Piece');
+
   # Somewhere else ...
 
   my $type = $class->column_type('column_name');
@@ -29,9 +33,6 @@ as your base class, use this instead.
 use strict;
 use base 'Class::DBI';
 
-use vars qw($VERSION);
-$VERSION = '0.21';
-
 =head1 METHODS
 
 =head2 set_up_table
@@ -71,6 +72,44 @@ sub set_up_table {
 	$class->columns(All     => @cols);
 }
 
+=head2 autoinflate
+
+  __PACKAGE__->autoinflate(column_type => 'Inflation::Class');
+
+  __PACKAGE__->autoinflate(timestamp => 'Time::Piece');
+  __PACKAGE__->autoinflate(dates => 'Time::Piece');
+
+This will automatically set up has_a() relationships for all columns of
+the specified type to the given class.
+
+We currently assume that all classess passed will be able to inflate
+and deflate without needing extra has_a arguments, with the example of
+Time::Piece objects, which we deal with using Time::Piece::mysql (which
+you'll have to have installed!).
+
+The special type 'dates' will autoinflate all columns of type date,
+datetime or timestamp.
+
+=cut
+
+sub autoinflate {
+	my ($class, %how) = @_;
+	$how{$_} ||= $how{dates} for qw/date datetime timestamp/;
+	my $info = $class->_column_info;
+	foreach my $col (keys %$info) {
+		(my $type = $info->{$col}->{type}) =~ s/\W.*//;
+		next unless $how{$type};
+		my %args;
+		if ($how{$type} eq "Time::Piece") {
+			eval "use Time::Piece::MySQL";
+			$class->_croak($@) if $@;
+			$args{inflate} = "from_mysql_$type";
+			$args{deflate} = "mysql_$type";
+		}
+		$class->has_a($col => $how{$type}, %args);
+	}
+}
+
 =head2 create_table
 
 	$class->create_table(q{
@@ -122,13 +161,16 @@ This returns the 'type' of this table (VARCHAR(20), BIGINT, etc.)
 
 =cut
 
-sub column_type {
-	my $ref   = shift;
-	my $class = ref($ref) || $ref;
-	my $col   = shift or die "Need a column for column_type";
+sub _column_info {
+	my $class = shift;
 	(my $sth = $class->sql_desc_table)->execute;
-	my ($series) = grep $_->[0] eq $col, $sth->fetchall;
-	return $series->[1];
+	return { map { $_->{field} => $_ } $sth->fetchall_hash };
+}
+
+sub column_type {
+	my $class = shift;
+	my $col = shift or die "Need a column for column_type";
+	return $class->_column_info->{$col}->{type};
 }
 
 =head2 enum_vals
@@ -140,12 +182,10 @@ This returns a list of the allowable values for an ENUM column.
 =cut
 
 sub enum_vals {
-	my $ref   = shift;
-	my $class = ref($ref) || $ref;
-	my $col   = shift or die "Need a column for enum vals";
-	(my $sth = $class->sql_desc_table)->execute;
-	my ($series) = grep $_->[0] eq $col, $sth->fetchall;
-	$series->[1] =~ /enum\((.*?)\)/ or die "$col is not an ENUM column";
+	my $class  = shift;
+	my $col    = shift or die "Need a column for enum_vals";
+	my $series = $class->_column_info->{$col}->{type};
+	$series =~ /enum\((.*?)\)/ or die "$col is not an ENUM column";
 	(my $enum = $1) =~ s/'//g;
 	return split /,/, $enum;
 }
